@@ -1179,7 +1179,7 @@ class WordToken(models.Model):
                         ('Following distance to pause', self.getFollDistToPause()),
                         ('Previous semantic predictability', self.getPrevSemPred()),
                         ('Following semantic predictability',self.getFollSemPred()))
-            lex = OrderedDict(('Word': str(self.WordType)),
+            lex = OrderedDict(('Word', str(self.WordType)),
                             ('Underlying representation', self.WordType.getUR()),
                             ('Buckeye frequency', self.WordType.getFreq()),
                             ('Buckeye single-phone probability', sp),
